Input

pub struct Input {
    pub subject: FHIRUri,
    pub code: Option<Vec<FHIRString>>,
    pub system: Option<FHIRUri>,
    pub coding: Option<Vec<Coding>>,
    pub duration: Option<FHIRDecimal>,
    pub period: Option<Period>,
    pub statistic: Vec<FHIRCode>,
    pub include: Option<FHIRBoolean>,
    pub limit: Option<FHIRPositiveInt>,
}

Fields

subject: FHIRUri

The subject of the relevant Observations, which has the value of the Observation.subject.reference. E.g. ‘Patient/123’. Reference can be to an absolute URL, but servers only perform stats on their own observations

code: Option<Vec<FHIRString>>

The test code(s) upon which the statistics are being performed. Provide along with a system, or as a coding. For example, the LOINC code = 2339-0 (Glucose [Mass/​volume] in Blood) will evaluate all relevant Observations with this code in Observation.code and Observation.component.code. For LOINC codes that are panels, e.g., 85354-9(Blood pressure panel with all children optional), the stats operation returns statistics for each of the individual panel measurements. That means it will include and evaluate all values grouped by code for all the individual observations that are: 1) referenced in .related for .related.type = ‘has-member’ and 2) component observations in Observation.component.

system: Option<FHIRUri>

The system for the code(s). Or provide a coding instead

coding: Option<Vec<Coding>>

The test code upon which the statistics are being performed, as a Coding

duration: Option<FHIRDecimal>

The time period of interest given as hours. For example, the duration = “1” represents the last hour - the time period from on hour ago to now

period: Option<Period>

The time period over which the calculations to be performed, if a duration is not provided

statistic: Vec<FHIRCode>

average|max|min|count The statistical operations to be performed on the relevant operations. Multiple statistics operations can be specified. These codes are defined here

include: Option<FHIRBoolean>

Whether to return the observations on which the statistics are based

limit: Option<FHIRPositiveInt>

If an include parameter is specified, a limit may also be specified to limit the number of source Observations returned. If the include paramter is absent or equal to “false” the limit parameter SHALL be ignored by the server