pub struct Output {
pub statistics: Vec<Observation>,
pub source: Option<Vec<Observation>>,
}Fields
statistics: Vec<Observation>A set of observations, one observation for each code, each containing one component for each statistic. The Observation.component.code contains the statistic, and is relative to the Observation.code and cannot be interpreted independently. The Observation will also contain a subject, effectivePeriod, and code reflecting the input parameters. The status is fixed to final.
source: Option<Vec<Observation>>Source observations on which the statistics are based